@@ -1,20 +1,9 @@
-/*************************************************************************
- *  Copyright (C) 2008, 2010 by Volker Lanz <vl@fidra.de>                *
- *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2014-2020 Andrius Štikonas <andrius@stikonas.eu>
+
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "gui/parttablewidget.h"
 #include "util/guihelpers.h"
@@ -54,6 +43,9 @@ void PartTableWidget::setPartitionTable(const PartitionTable* ptable)
             PartWidget* w = new PartWidget(this, p);
             w->setVisible(true);
             w->setFileSystemColorCode(GuiHelpers::fileSystemColorCodesFromSettings());
+            const auto children = w->childWidgets();
+            for (const auto &child : children)
+                child->setFileSystemColorCode(GuiHelpers::fileSystemColorCodesFromSettings());
         }
     }
 
@@ -103,7 +95,7 @@ void PartTableWidget::setActiveWidget(PartWidget* p)
     if (p != nullptr)
         p->setActive(true);
 
-    emit itemSelectionChanged(p);
+    Q_EMIT itemSelectionChanged(p);
 
     update();
 }
@@ -175,5 +167,5 @@ void PartTableWidget::mouseDoubleClickEvent(QMouseEvent* event)
     const PartWidget* child = static_cast<PartWidget*>(childAt(event->pos()));
 
     if (child != nullptr)
-        emit itemDoubleClicked(child);
+        Q_EMIT itemDoubleClicked(child);
 }
